==> apache-servicecomb-java-chassis-distribution-1.1.0-src.zip: apache-servicecomb-java-chassis-distribution-1.1.0-src/swagger/swagger-generator/generator-springmvc/src/test/java/org/apache/servicecomb/swagger/generator/springmvc/Echo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.swagger.generator.springmvc;

import org.apache.servicecomb.foundation.test.scaffolding.model.Color;
import org.apache.servicecomb.swagger.extend.annotations.RawJsonRequestBody;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

@RequestMapping(
    path = "Echo",
    method = {RequestMethod.PUT},
    consumes = {"a", "b"},
    produces = {"a", "b"})
public class Echo {

  @RequestMapping
  public void emptyPath() {
  }

  @RequestMapping(method = {RequestMethod.GET, RequestMethod.POST})
  public void multiHttpMethod() {
  }

  @RequestMapping
  public void inheritHttpMethod(int query) {
  }

  @RequestMapping
  public void rawJsonStringMethod(@RawJsonRequestBody String jsonInput) {
  }

  @RequestMapping
  public void enumBody(@RequestBody Color color) {
  }
}

==> apache-servicecomb-java-chassis-distribution-1.2.0-src.zip: apache-servicecomb-java-chassis-distribution-1.2.0-src/swagger/swagger-generator/generator-springmvc/src/test/java/org/apache/servicecomb/swagger/generator/springmvc/Echo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.swagger.generator.springmvc;

import java.util.List;
import java.util.concurrent.CompletableFuture;

import org.apache.servicecomb.foundation.test.scaffolding.model.Color;
import org.apache.servicecomb.swagger.extend.annotations.RawJsonRequestBody;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

@RequestMapping(
    path = "Echo",
    method = {RequestMethod.PUT},
    consumes = {"a", "b"},
    produces = {"a", "b"})
public class Echo {

  @RequestMapping
  public void emptyPath() {
  }

  @RequestMapping(method = {RequestMethod.GET, RequestMethod.POST})
  public void multiHttpMethod() {
  }

  @RequestMapping
  public void inheritHttpMethod(int query) {
  }

  @RequestMapping
  public void rawJsonStringMethod(@RawJsonRequestBody String jsonInput) {
  }

  @RequestMapping
  public void enumBody(@RequestBody Color color) {
  }

  @RequestMapping
  public CompletableFuture<ResponseEntity<List<String>>> asyncResponseEntity() {
    return null;
  }
}
